Chrfinder package
=================

Submodules
----------

Chrfinder.Chrfinder module
--------------------------

.. automodule:: Chrfinder.Chrfinder
   :members:
   :undoc-members:
   :show-inheritance:

Chrfinder.classify module
-------------------------

.. automodule:: Chrfinder.classify
   :members:
   :undoc-members:
   :show-inheritance:

Chrfinder.pka\_lookup module
----------------------------

.. automodule:: Chrfinder.pka_lookup
   :members:
   :undoc-members:
   :show-inheritance:

Chrfinder.pubchemprops module
-----------------------------

.. automodule:: Chrfinder.pubchemprops
   :members:
   :undoc-members:
   :show-inheritance:

Chrfinder.search\_pka module
----------------------------

.. automodule:: Chrfinder.search_pka
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: Chrfinder
   :members:
   :undoc-members:
   :show-inheritance:
